;; Written by: Lee Ambrosius, HyperPics (http://www.hyperpics.com)
;; Created on: 11/12/02
;; Last Revised on: 12/07/04

;; 12/07/04
;; Removed loopping through each filter to improve performance

;; Routine deletes all the Layer Filters from the drawing.
;; Works with AutoCAD 2000 through 2005

(defun c:RemoveLayerFilters ( / acDoc modelSpace extDict acLayer layerTable xRec)
  (setq save-cmdecho (getvar "CMDECHO"))
  (setvar "CMDECHO" 0)

  (command "._undo" "begin")
  
  ;; Get the active drawing
  (setq acDoc (vlax-get-property (vlax-get-acad-object) 'ActiveDocument))

  ;; Get the Layers Collection for the Drawing
  (setq layerTable (vlax-get-property acDoc 'Layers))

  ;; Get the Extension Dictionary for Layer Table
  (setq extDict (vlax-invoke-method layerTable 'GetExtensionDictionary))
  
  ;; Check to see if the Layer exists in the drawing
  (if (/= (type (setq layerFilters (vl-catch-all-apply 'vlax-invoke-method (list extDict 'Item "ACAD_LAYERFILTERS")))) 'VL-CATCH-ALL-APPLY-ERROR)
    (vl-catch-all-apply 'vla-Remove (list extDict "ACAD_LAYERFILTERS"))

;; Removed 12/07/04 to improve performance
;;    ;; Loop through the Layer Extension Dictionary
;;    (vlax-for xRec layerFilters
;;      (vlax-invoke-method xRec 'Delete)
;;    )
  )

  ;; For 2005 we need to remove the contents of another Extension Dictionary called ACLYDICTIONARY
  (if (> (atof (getvar "ACADVER")) 16.0)
    ;; Check to see if the Layer exists in the drawing
    (if (/= (type (setq layerFilters (vl-catch-all-apply 'vlax-invoke-method (list extDict 'Item "ACLYDICTIONARY")))) 'VL-CATCH-ALL-APPLY-ERROR)
      (vl-catch-all-apply 'vla-Remove (list extDict "ACLYDICTIONARY"))

;; Removed 12/07/04 to improve performance
;;      ;; Loop through the Layer Extension Dictionary
;;      (vlax-for xRec layerFilters
;;        (vlax-invoke-method xRec 'Delete)
;;      )
    )
  )

  (command "._undo" "end")
  (setvar "CMDECHO" 1)
 (princ)  
)

(prompt "\nEnter RLF or RemoveLayerFilters to remove all Layer Filters in the drawing.")

(defun c:RLF() (c:RemoveLayerFilters))
(princ)